TEONITE Deployment and database migration tool
==============================================

<todo: some description of this tool>

This tool requires ``config.json`` which can be provided by ``-c/--config`` switch
